<?php
/**
 * 添加一篇文章
 * @version 1.0.0 首次引入
 * @param array $post 必需;数组格式,支持的字段列表请参考手册
 * @param bool $autoSave 可选;当分类与标签不存在时是否自动新增;默认:false
 * @return mixed 成功时返回obj,失败时null
 */
function articleSave($post=[], $autoSave=false)
{
    $post = DcArrayArgs($post,[
        'info_module'   => 'cms',
        'info_controll' => 'detail',
        'info_action'   => 'index',
        'info_staus'    => 'normal',
        'info_type'     => 'index',
    ]);
    $post = articleDataSet($post, $autoSave);
    
    config('common.validate_name','cms/Article');
        
    config('common.validate_scene','save');

    config('common.where_slug_unique',['info_module'=>['eq','cms'],'info_controll'=>['eq','detail']]);

    return \daicuo\Info::save($post, 'info_meta,term_map');
}

/**
 * 按ID删除一条或多条文章
 * @version 1.0.0 首次引入
 * @param mixed $ids 必需;多个用逗号分隔或使用数组传入(array|string);默认：空 
 * @return array ID作为键名,键值为删除结果(bool)
 */
function articleDelete($ids=[])
{
    $result = [];
    if(is_string($ids)){
        $ids = explode(',', $ids);
    }
    foreach($ids as $key=>$id){
        $result[$id] = \daicuo\Info::delete_id($id);
    }
    return $result;
}

/**
 * 修改一篇文章(需传入主键值作为更新条件)
 * @version 1.0.0 首次引入
 * @param array $post 必需;表单字段 {
 *     @type int $info_id 必需;按ID修改;默认：空
 * }
 * @param bool $autoSave 可选;当分类与标签不存在时是否自动新增;默认:false
 * @return mixed 成功时返回obj,失败时null
 */
function articleUpdate($post=[], $autoSave=false)
{
    $post = DcArrayArgs($post,[
        'info_module'   => 'cms',
        'info_controll' => 'detail',
        'info_action'   => 'index',
        'info_staus'    => 'normal',
        'info_type'     => 'index',
    ]);
    $post = articleDataSet($post, $autoSave);
    
    config('common.validate_name','cms/Article');
        
    config('common.validate_scene','update');

    config('common.where_slug_unique',['info_module'=>['eq','cms'],'info_controll'=>['eq','detail']]);
    
    return \daicuo\Info::update_id($post['info_id'], $post, 'info_meta,term_map');
}

/**
 * 按条件查询多条文章数据
 * @version 1.0.0 首次引入
 * @param array $args 必需;查询条件数组格式 {
 *     @type bool $cache 可选;是否缓存;默认：true
 *     @type int $limit 可选;分页大小;默认：0
 *     @type int $page 可选;当前分页;默认：0
 *     @type string $sort 可选;排序字段名(info_id|info_order|info_views|info_hits|meta_value_num);默认：info_id
 *     @type string $order 可选;排序方式(asc|desc);默认：asc
 *     @type string $search 可选;搜索关键词（info_name|info_slug|info_excerpt）;默认：空
 *     @type mixed $id 可选;内容ID限制条件(int|array);默认：空
 *     @type mixed $title 可选;标题限制条件(stirng|array);默认：空
 *     @type mixed $name 可选;名称限制条件(stirng|array);默认：空
 *     @type mixed $slug 可选;别名限制条件(stirng|array);默认：空
 *     @type mixde $action 可选;所属操作(stirng|array);默认：空
 *     @type mixed $term_id 可选;分类法ID限制条件(string|array);默认：空
 *     @type array $meta_query 可选;自定义字段(二维数组[key=>['eq','key'],value=>['in','key']]);默认：空
 *     @type string $status 可选;显示状态（normal|hidden|private）;默认：空
 *     @type string $result 可选;返回结果类型(array|obj);默认：array
 *     @type string $field 可选;查询字段;默认：*
 *     @type array $with 可选;自定义关联查询条件;默认：空
 *     @type array $view 可选;自定义视图查询条件;默认：空
 *     @type array $where 可选;自定义高级查询条件;默认：空
 *     @type array $paginate 可选;自定义高级分页参数;默认：空
 * }
 * @return mixed 查询结果（array|null）
 */
function articleSelect($args)
{
    $args = DcArrayArgs($args,[
        'cache'    => 'true',
        'result'   => 'array',
        'module'   => 'cms',
        'controll' => 'detail',
    ]);
    //mysql5.7.X only_full_group_by
    if($args['meta_key'] && $args['sort']=='meta_value_num'){
        $args['order'] = 'desc,info.info_id desc';
        $args['group'] = 'info.info_id,info_meta.info_meta_value';
    }
    return DcInfoSelect($args);
}

/**
 * 按条件查询一条文章
 * @version 1.0.0 首次引入
 * @param array $args 必需;查询条件数组格式 {
 *     @type bool $cache 可选;是否缓存;默认：true
 *     @type string $status 可选;显示状态（normal|hidden）;默认：空
 *     @type mixed $id 可选;内容ID(stirng|array);默认：空
 *     @type mixed $name 可选;内容名称(stirng|array);默认：空
 *     @type mixed $slug 可选;内容别名(stirng|array);默认：空
 *     @type mixed $title 可选;内容别名(stirng|array);默认：空
 *     @type mixed $user_id 可选;用户ID(stirng|array);默认：空
 *     @type array $with 可选;自定义关联查询条件;默认：空
 *     @type array $view 可选;自定义视图查询条件;默认：空
 *     @type array $where 可选;自定义高级查询条件;默认：空
 * }
 * @return mixed 查询结果（array|null）
 */
function articleGet($args)
{
    $args = DcArrayArgs($args,[
        'cache'    => 'true',
        'module'   => 'cms',
    ]);
    return articleDataGet( DcInfoFind($args) );
}

/**
 * 按ID快速获取一篇文章
 * @version 1.0.0 首次引入
 * @param int $value 必需;Id值；默认：空
 * @param bool $cache 可选;是否缓存;默认：true
 * @param string $status 可选;数据状态;默认：normal
 * @return mixed 查询结果(obj|null)
 */
function articleId($value='', $cache=true, $status='normal')
{
    return articleDataGet( \daicuo\Info::get_by('info_id', $value, $cache, false, $status) );
}

/**
 * 按SLUG快速获取一篇文章
 * @version 1.0.0 首次引入
 * @param int $value 必需;Id值；默认：空
 * @param bool $cache 可选;是否缓存;默认：true
 * @param string $status 可选;数据状态;默认：normal
 * @return mixed 查询结果(obj|null)
 */
function articleSlug($value='', $cache=true, $status='normal')
{
    if (!$value) {
        return null;
    }
    $args = [];
    $args['cache'] = $cache;
    $args['where']['info_module']   = ['eq', 'cms'];
    $args['where']['info_status']   = ['eq', $status];
    $args['where']['info_slug']     = ['eq', $value];
    return articleDataGet( \daicuo\Info::meta_attr( \daicuo\Info::get($args) ) );
}

/**
 * 按NAME快速获取一条文章
 * @version 1.0.0 首次引入
 * @param int $value 必需;Id值；默认：空
 * @param bool $cache 可选;是否缓存;默认：true
 * @param string $status 可选;数据状态;默认：normal
 * @return mixed 查询结果(obj|null)
 */
function articleName($value='', $cache=true, $status='normal')
{
    return articleDataGet( \daicuo\Info::get_by('info_name', $value, $cache, false, $status) );
}

/**
 * 按ID快速获取上一篇文章列表
 * @version 1.0.0 首次引入
 * @param int $id 必需;Id值；默认：空
 * @return mixed 查询结果(obj|null)
 */
function articlePrev($id=1, $limit=1)
{
    return articleSelect(['status'=>'normal','limit'=>$limit,'id'=>['lt',$id],'sort'=>'info_id','order'=>'desc']);
}

/**
 * 按ID快速获取下一篇文章列表
 * @version 1.0.0 首次引入
 * @param int $id 必需;Id值；默认：空
 * @return mixed 查询结果(obj|null)
 */
function articleNext($id=1, $limit=1)
{
    return articleSelect(['status'=>'normal','limit'=>$limit,'id'=>['gt',$id],'sort'=>'info_id','order'=>'asc']);
}


/**
 * 文章属性选项（checkOption）
 * @version 1.0.0 首次引入
 * @return array 处理后的数据
 */
function articleAttrOption(){
    return [
        'top'       => lang('article_top'),
        'head'     => lang('article_head'),
        'hot'       => lang('article_hot'),
        'recommend' => lang('article_recommend'),
    ];
}

/**
 * 文章属性值转化为(checkValue)
 * @version 1.0.0 首次引入
 * @param array $data 必需;查询的数据;默认:空
 * @return array 处理后的数据
 */
function articleAttrValue($data=[]){
    $value = [];
    $attrKeys = array_keys(articleAttrOption());
    foreach($attrKeys as $key=>$field){
        if($data['article_'.$field]){
           array_push($value,$field); 
        }
    }
    return $value;
}

/**
 * 文章形式选项
 * @version 1.0.0 首次引入
 * @return array 处理后的数据
 */
function articleTypeOption(){
    return [
        'index' => '标准',
        'image' => '图文',
        'album' => '相册',
        'video' => '视频',
        'auido' => '音频',
        'link'  => '链接',
    ];
}

/**
 * 获取文章模型所有字段
 * @version 1.0.0 首次引入
 * @return mixed 成功时返回array,失败时null
 */
function articleFields()
{
    $fields = array_keys(DcFields('info'));
    $fieldsMeta = array_keys(DcFields(config('custom_fields.info_meta')));
    if(is_array($fields) && is_array($fieldsMeta)){
        return array_merge($fields, $fieldsMeta);
    }
    return null;
}

/**
 * 数据修改器（表单处理）
 * @version 1.0.0 首次引入
 * @param array $post 必需;数组格式,支持的字段列表请参考手册;默认:空
 * @param bool $autoSave 可选;当分类与标签不存在时是否自动新增;默认:false
 * @return array 处理后的数据
 */
function articleDataSet($post=[], $autoSave=false){
    //属性处理
    $post['article_top']       = 0;
    $post['article_first']     = 0;
    $post['article_hot']       = 0;
    $post['article_recommend'] = 0;
    if(in_array('top', $post['article_attr'])){
        $post['article_top'] = 1;
    }
    if(in_array('first', $post['article_attr'])){
        $post['article_first'] = 1;
    }
    if(in_array('hot', $post['article_attr'])){
        $post['article_hot'] = 1;
    }
    if(in_array('recommend', $post['article_attr'])){
        $post['article_recommend'] = 1;
    }
    //置顶处理
    if($post['article_top']){
        $post['info_order'] = DcEmpty($post['info_order'],99);
    }
    //分类处理（category_name、category_id可自动合并）
    $post['term_id'] = [];
    if($post['category_name']){
        $post['category_id'] = DcArrayArgs(cmsTermNameToIds($post['category_name'], 'category', $autoSave), $post['category_id']); ;
    }
    if($post['category_id']){
        $post['term_id'] = DcArrayArgs($post['category_id'], $post['term_id']);
    }
    //未分类
    if(!$post['term_id']){
        $post['term_id'] = ['1'];
    }
    //标签处理（tag_name、tag_id可自动合并）
    if($post['tag_name']){
        $post['tag_id'] = DcArrayArgs(cmsTermNameToIds($post['tag_name'], 'tag', $autoSave), $post['tag_id']); ;
    }
    if($post['tag_id']){
        $post['term_id'] = DcArrayArgs($post['tag_id'], $post['term_id']);
    }
    //摘要截取
    if(!$post['info_excerpt']){
       $post['info_excerpt'] = cmsSubstr($post['info_content'], 0, 140, true);
    }
    //别名处理
    if(config('cms.slug_first') && !$post['info_slug']){
        $post['info_slug'] = \daicuo\Pinyin::get($post['info_name'], true);
    }
    //首字母
    if(!$post['info_letter']){
        $post['info_letter'] = substr($post['info_slug'], 0, 1);
    }
    //去除不需要的字段
    unset($post['article_attr']);
    unset($post['category_name']);
    unset($post['category_id']);
    unset($post['tag_name']);
    unset($post['tag_id']);
    //返回结果
    return $post;
}

/**
 * 数据获取器
 * @version 1.0.0 首次引入
 * @param array $data 必需;数组格式,支持的字段列表请参考手册;默认:空
 * @return array 处理后的数据
 */
function articleDataGet($data=[]){
    $data['article_attr'] = articleAttrValue($data);
    return $data;
}

/**********************************************************************************************************/

/**
 * 添加一个单页
 * @version 1.0.0 首次引入
 * @param array $post 必需;数组格式,支持的字段列表请参考手册
 * @return mixed 成功时返回obj,失败时null
 */
function cmsPageSave($post=[])
{
    $post = DcArrayArgs($post,[
        'info_module'   => 'cms',
        'info_controll' => 'page',
        'info_staus'    => 'normal',
        'info_tpl'      => 'index',
    ]);
    
    $module = DcEmpty($post['info_module'], 'cms');
    
    config('common.validate_name', $module.'/Page');
        
    config('common.validate_scene', 'save');

    config('common.where_slug_unique', ['info_module'=>['eq',$module],'info_controll'=>['eq','page']]);

    return \daicuo\Info::save($post, 'info_meta');
}

/**
 * 删除一条或多条单页
 * @version 1.0.0 首次引入
 * @param mixed $ids 必需;多个用逗号分隔或使用数组传入(array|string);默认：空 
 * @return array ID作为键名,键值为删除结果(bool)
 */
function cmsPageDelete($ids=[])
{
    $result = [];
    if(is_string($ids)){
        $ids = explode(',', $ids);
    }
    foreach($ids as $key=>$id){
        $result[$id] = \daicuo\Info::delete_id($id);
    }
    return $result;
}

/**
 * 修改一个单页(需传入主键值作为更新条件)
 * @version 1.0.0 首次引入
 * @param array $post 必需;数组格式,支持的字段列表请参考手册 {
 *     @type int $info_id 必需;按ID修改;默认：空
 * }
 * @return mixed 成功时返回obj,失败时null
 */
function cmsPageUpdate($post=[])
{
    $post = DcArrayArgs($post,[
        'info_module'   => 'cms',
        'info_controll' => 'page',
        'info_tpl'      => 'index',
    ]);
    
    $module = DcEmpty($post['info_module'], 'cms');
    
    config('common.validate_name', $module.'/Page');
        
    config('common.validate_scene', 'update');

    config('common.where_slug_unique', ['info_module'=>['eq',$module],'info_controll'=>['eq','page']]);
    
    return \daicuo\Info::update_id($post['info_id'], $post, 'info_meta');
}

/**
 * 按条件查询一条单页
 * @version 1.0.0 首次引入
 * @param array $args 必需;查询条件数组格式 {
 *     @type bool $cache 可选;是否缓存;默认：true
 *     @type string $status 可选;显示状态（normal|hidden）;默认：空
 *     @type mixed $id 可选;内容ID(stirng|array);默认：空
 *     @type mixed $name 可选;内容名称(stirng|array);默认：空
 *     @type mixed $slug 可选;内容别名(stirng|array);默认：空
 *     @type mixed $title 可选;内容别名(stirng|array);默认：空
 *     @type mixed $user_id 可选;用户ID(stirng|array);默认：空
 *     @type array $with 可选;自定义关联查询条件;默认：空
 *     @type array $view 可选;自定义视图查询条件;默认：空
 *     @type array $where 可选;自定义高级查询条件;默认：空
 * }
 * @return array 查询结果
 */
function cmsPageGet($args=[])
{
    $args = DcArrayArgs($args,[
        'cache'    => true,
        'module'   => 'cms',
        'controll' => 'page',
        'with'     => 'info_meta',
    ]);
    
    $args = DcArrayEmpty($args);
    
    return \daicuo\Info::meta_attr( DcInfoFind($args) );
}

/**
 * 按条件获取多条单页
 * @version 1.0.0 首次引入
 * @param array $args 必需;查询条件数组格式 {
 *     @type bool $cache 可选;是否缓存;默认：true
 *     @type int $limit 可选;分页大小;默认：0
 *     @type int $page 可选;当前分页;默认：0
 *     @type string $sort 可选;排序字段名;默认：空
 *     @type string $order 可选;排序方式(asc|desc);默认：asc
 *     @type string $status 可选;显示状态（normal|hidden）;默认：空
 *     @type string $result 可选;返回数据格式(array|obj);默认：array
 *     @type array $where 可选;自定义高级查询条件;默认：空
 *     @type array $paginate 可选;自定义高级分页参数;默认：空
 * }
 * @return mixed 查询结果obj|null
 */
function cmsPageSelect($args=[])
{
    $args = DcArrayArgs($args,[
        'cache'    => true,
        'result'   => 'array',
        'module'   => 'cms',
        'controll' => 'page',
        'with'     => 'info_meta',
    ]);
    return DcInfoSelect($args);
}

/**
 * 按ID快速获取一条单页
 * @version 1.0.0 首次引入
 * @param int $value 必需;Id值;默认：空
 * @param bool $cache 可选;是否缓存;默认：true
 * @param string $status 可选;数据状态;默认：空
 * @return mixed 查询结果(obj|null)
 */
function cmsPageId($value='', $cache=true, $status='')
{
    if (!$value) {
        return null;
    }
    return cmsPageGet([
        'id'     => $value,
        'cache'  => $cache,
        'status' => $status,
    ]);
}

/**
 * 按SLUG快速获取一条单页
 * @version 1.0.0 首次引入
 * @param int $value 必需;Id值;默认：空
 * @param bool $cache 可选;是否缓存;默认：true
 * @param string $status 可选;数据状态;默认：空
 * @return mixed 查询结果(obj|null)
 */
function cmsPageSlug($value='', $cache=true, $status='')
{
    if (!$value) {
        return null;
    }
    return cmsPageGet([
        'slug'   => $value,
        'cache'  => $cache,
        'status' => $status,
    ]);
}

/**
 * 按NAME快速获取一条内容数据
 * @version 1.0.0 首次引入
 * @param int $value 必需;Id值；默认：空
 * @param bool $cache 可选;是否缓存;默认：true
 * @param string $status 可选;数据状态;默认：空
 * @return mixed 查询结果(obj|null)
 */
function cmsPageName($value='', $cache=true, $status='')
{
    if (!$value) {
        return null;
    }
    return cmsPageGet([
        'name'   => $value,
        'cache'  => $cache,
        'status' => $status,
    ]);
}

/**********************************************************************************************************/
/**
 * 按条件获取多个导航菜单
 * @version 1.0.0 首次引入
 * @param array $args 必需;查询条件数组格式 {
 *     @type bool $cache 可选;是否缓存;默认：true
 *     @type string $result 可选;返回数据格式(array|tree|level);默认：array
 *     @type string $sort 可选;排序字段名;默认：term_order
 *     @type string $order 可选;排序方式(asc|desc);默认：asc
 *     @type string $status 可选;显示状态（normal|hidden）;默认：空
 *     @type string $module 可选;模型名称;默认：空
 *     @type string $controll 可选;控制器名称;默认：空
 *     @type string $action 可选;导航菜单标识(navbar|sitebar|navs|links|ico|image);默认：navbar
 *     @type string $info 可选;附加属性;默认：空
 *     @type array $where 可选;自定义高级查询条件;默认：空
 * }
 * @return mixed 查询结果obj|null
 */
function cmsNavsSelect($args=[])
{
    //手动处理返回结果
    $result = DcEmpty($args['result'], 'tree');
    unset($args['result']);
    //默认参数(固定返回Array)
    $args = DcArrayArgs($args,[
        'cache'  => true,
        'type'   => 'navs',
        'result' => 'array',
        'sort'   => 'term_order desc,term_id',
        'order'  => 'desc',
        'action' => 'navbar',
    ]);
    //查询导航栏标识时不同的查询方法（需合并分类的导航栏属性）
    if($args['action'] == 'navbar'){
        $whereOr = [];
        $whereOr[0] = function ($query) {$query
                  ->where('term_status', 'eq', 'normal')
                  ->where('term_type', 'eq', 'category')
                  ->where('term_meta_key', 'eq', 'term_navbar')
                  ->where('term_meta_value', 'eq', 'yes');
        };
        $args = DcArrayArgs([
            //'fetchSql'   => true,
            'type'       => 'navs',
            'group'      => 'term.term_id',
            'field'      => '',
            'view'       => [
                ['term', '*'],
                ['term_meta', NULL, 'term_meta.term_id=term.term_id']
            ],
            'whereOr'    => $whereOr,
        ],$args);
    }
    //调用查询接口
    $items = DcTermSelect( $args );
    //转换器
    foreach($items as $key=>$value){
        $items[$key] = cmsNavsDataGet($value);
    }
    //树形结构
    if($result == 'tree' && $items){
        return list_to_tree($items, 'navs_id', 'navs_parent');
    }
    //还原层级
    if($result == 'level' && $items){
        return tree_to_level(list_to_tree($items, 'navs_id', 'navs_parent'), 'navs_name');
    }
    //普通数组
    return $items;
}

/**
 * 按ID快速获取一条导航菜单
 * @version 1.0.0 首次引入
 * @param int $value 必需;Id值；默认：空
 * @param bool $cache 可选;是否缓存;默认：true
 * @param string $status 可选;数据状态;默认：空
 * @return mixed 查询结果(obj|null)
 */
function cmsNavsId($value='', $cache=true, $status='')
{
    if (!$value) {
        return null;
    }
    return cmsNavsDataGet( \daicuo\Term::get_by('term_id', $value, $cache, 'navs', $status) );
}

/**
 * 导航菜单数据获取器
 * @version 1.0.0 首次引入
 * @param array $data 必需;数组格式,支持的字段列表请参考手册;默认:空
 * @return array 处理后的数据
 */
function cmsNavsDataGet($data=[]){
    if(!$data){
        return null;
    }
    //分类是否展示导航
    if($data['term_navbar']){
        $data['term_link'] = cmsUrlCategory($data);
    }else{
        $data['term_link'] = cmsUrlCheck($data['navs_url']);
    }
    //字段映射
    $navs = [];
    foreach($data as $key=>$value){
        $navs[str_replace('term_','navs_',$key)] = $value;
    }
    unset($data);
    return $navs;
}

/**
 * 获取菜单select关系
 * @version 1.0.0 首次引入
 * @param array $args 必需;查询条件数组格式 {
 *     @type bool $cache 可选;是否缓存;默认：false
 *     @type string $sort 可选;排序字段名(term_id|term_parent|term_order|trem_count|term_meta_key|term_meta_value|meta_value_num);默认：term_order
 *     @type string $order 可选;排序方式(asc|desc);默认：asc
 *     @type string $search 可选;搜索关键词（名称与别名）;默认：空
 *     @type string $status 可选;显示状态（normal|hidden）;默认：空
 *     @type string $module 可选;队列类型(stirng|array),固定范围(category|tag);默认：category
 *     @type string $parent 可选;父级ID(int|array);默认：空
 * }
 * @return mixed 查询结果(array|null)
 */
function cmsNavsOption($args=[]){
    $args = DcArrayArgs($args,[
        'type'       => 'navs',
        'fieldKey'   => 'term_id',
        'fieldValue' => 'term_name',
        'isSelect'   => true,
        'status'     => '',
    ]);
    return \daicuo\Term::Option($args);
}

/**********************************************************************************************************/

/**
 * 按条件获取多个网站分类
 * @version 1.0.0 首次引入
 * @param array $args 必需;查询条件数组格式 {
 *     @type bool $cache 可选;是否缓存;默认：true
 *     @type int $limit 可选;分页大小;默认：0
 *     @type int $page 可选;当前分页;默认：0
 *     @type string $sort 可选;排序字段名;默认：op_order
 *     @type string $order 可选;排序方式(asc|desc);默认：asc
 *     @type string $status 可选;显示状态（normal|hidden）;默认：空
 *     @type string $module 可选;模型名称;默认：空
 *     @type string $result 可选;模型名称;默认：空
 *     @type array $where 可选;自定义高级查询条件;默认：空
 *     @type array $paginate 可选;自定义高级分页参数;默认：空
 * }
 * @return mixed 查询结果obj|null
 */
function cmsCategorySelect($args=[])
{
    return DcTermSelect( DcArrayArgs($args,[
        'cache'   => true,
        'result'  => 'array',
        'type'    => 'category',
        //'module'  => 'cms',
    ]) );
}

/**
 * 按ID快速获取分类信息
 * @version 1.0.0 首次引入
 * @param int $value 必需;Id值;默认：空
 * @param bool $cache 可选;是否缓存;默认：true
 * @param string $status 可选;数据状态;默认：normal
 * @return mixed 查询结果(array|null)
 */
function cmsCategoryId($value='', $cache=true, $status='normal')
{
    return \daicuo\Term::get_by('term_id', $value, $cache, 'category', $status);
}

/**
 * 按别名快速获取分类信息
 * @version 1.0.0 首次引入
 * @param string $value 必需;别名值;默认：空
 * @param bool $cache 可选;是否缓存;默认：true
 * @param string $status 可选;数据状态;默认：normal
 * @return mixed 查询结果(array|null)
 */
function cmsCategorySlug($value='', $cache=true, $status='normal')
{
    return \daicuo\Term::get_by('term_slug', $value, $cache, 'category', $status);
}

/**
 * 按分类名称快速获取分类信息
 * @version 1.0.0 首次引入
 * @param string $value 必需;分类名称;默认：空
 * @param bool $cache 可选;是否缓存;默认：true
 * @param string $status 可选;数据状态;默认：normal
 * @return mixed 查询结果(array|null)
 */
function cmsCategoryName($value='', $cache=true, $status='normal')
{
    return \daicuo\Term::get_by('term_name', $value, $cache, 'category', $status);
}

/**
 * 按条件获取多个标签信息
 * @version 1.0.0 首次引入
 * @param array $args 必需;查询条件数组格式 {
 *     @type bool $cache 可选;是否缓存;默认：true
 *     @type int $limit 可选;分页大小;默认：0
 *     @type int $page 可选;当前分页;默认：0
 *     @type string $sort 可选;排序字段名;默认：op_order
 *     @type string $order 可选;排序方式(asc|desc);默认：asc
 *     @type string $status 可选;显示状态（normal|hidden）;默认：空
 *     @type string $module 可选;模型名称;默认：空
 *     @type string $result 可选;模型名称;默认：空
 *     @type array $where 可选;自定义高级查询条件;默认：空
 *     @type array $paginate 可选;自定义高级分页参数;默认：空
 * }
 * @return mixed 查询结果obj|null
 */
function cmsTagSelect($args=[])
{
    return DcTermSelect( DcArrayArgs($args,[
        'cache'   => true,
        'result'  => 'array',
        'type'    => 'tag',
        //'module'  => 'cms',
    ]) );
}

/**
 * 按ID快速获取标签信息
 * @version 1.0.0 首次引入
 * @param int $value 必需;Id值;默认：空
 * @param bool $cache 可选;是否缓存;默认：true
 * @param string $status 可选;数据状态;默认：normal
 * @return mixed 查询结果(array|null)
 */
function cmsTagId($value='', $cache=true, $status='normal')
{
    return \daicuo\Term::get_by('term_id', $value, $cache, 'tag', $status);
}

/**
 * 按别名快速获取标签信息
 * @version 1.0.0 首次引入
 * @param string $value 必需;别名值;默认：空
 * @param bool $cache 可选;是否缓存;默认：true
 * @param string $status 可选;数据状态;默认：normal
 * @return mixed 查询结果(array|null)
 */
function cmsTagSlug($value='', $cache=true, $status='normal')
{
    return \daicuo\Term::get_by('term_slug', $value, $cache, 'tag', $status);
}

/**
 * 按名称快速获取标签信息
 * @version 1.0.0 首次引入
 * @param string $value 必需;分类名称;默认：空
 * @param bool $cache 可选;是否缓存;默认：true
 * @param string $status 可选;数据状态;默认：normal
 * @return mixed 查询结果(array|null)
 */
function cmsTagName($value='', $cache=true, $status='normal')
{
    return \daicuo\Term::get_by('term_name', $value, $cache, 'tag', $status);
}

/**
 * 快速获取多个热门标签列表的某一个字段
 * @version 1.0.0 首次引入
 * @param int $limit 必需;数量限制；默认：10
 * @param string $field 可选;返回字段;默认：term_name
 * @return mixed 查询结果(array|null)
 */
function cmsTags($limit=10, $field='term_name')
{
    return array_column(cmsTagSelect([
        'status'=> 'normal',
        'limit' => $limit,
        'sort'  => 'term_count desc,term_id',
        'order' => 'desc',
    ]), $field);
}

/**
 * 多个队列名转化为多个队例ID
 * @version 1.0.0 首次引入
 * @param mixed $names 必需;多个队列名称,逗号分隔或数组(string|array);默认：空
 * @param string $type 必需;队例类型(category|tag);默认：category
 * @param bool $save 可选;是否自动新增不存在的关键字;默认：flase
 * @return array 父级ID值列表
 */
function cmsTermNameToIds($names='', $type='category', $save=false){
    if(!$names){
        return 0;
    }
    if( is_string($names) ){
        $names = explode(',',$names);
    }
    $list = DcTermSelect([
        'field' => 'term_id,term_name,term_status',
        'cache' => false,
        'result'=> 'array',
        'type'  => $type,
        'with'  => '',
        'name'  => ['in', $names],
    ]);
    //只返回查询到的结果（不自动新增）
    if($save == false){
        return array_column($list, 'term_id');
    }
    
    /**************检测是否需要新增不存在的队列**************/
    //取消表单验证规则与场景
    config('common.validate_name', false);
    config('common.validate_scene', false);
    //定义别名规则
    config('common.where_slug_unique', ['term_type'=>['eq',$type]]);
    //定义队列关系（键名-队例名，键值-队例ID）
    $result = [];
    foreach($list as $key=>$value){
        $result[$value['term_name']] = $value['term_id'];
    }
    //遍历检测是否都存在
    foreach($names as $key=>$value){
        //新增不存在的队列
        if( !array_key_exists($value, $result) ){
            $result[$value] = \daicuo\Term::Save([
                'term_module'   => 'cms',
                'term_controll' => $type,
                'term_action'   => 'index',
                'term_type'     => $type,
                'term_name'     => $value,
                'term_slug'     => '',
            ]);
        }
    }
    //返回合并后的队列ID
    return array_values($result);
}


/**********************************************************************************************************/

/**
 * 提取HTML代码的图片地址
 * @version 1.0.0 首次引入
 * @param string $content 必需;待提取的正文内容HTML;空
 * @param string $result 可选;array|first|last;默认:array
 * @return mixed array|string 数组或链接
 */
function cmsImagePreg($content='',$result='array')
{
    //有后缀
    /*$preg="/<img.*?src=[\'|\"](.*?(?:[\.gif|\.jpg|\.png|\.jpeg|\.?]))[\'|\"].*?[\/]?>/";*/
    $preg = '/(src)=([\"|\']?)([^ \"\'>]+\.(gif|jpg|jpeg|bmp|png|webp))\\2/i';
    preg_match_all($preg, $content, $match);
    $images = $match[3];
    //无后缀
    if(!$images){
        preg_match_all('/<img.*?src=[\'|\"](.*?)[\'|\"].*?[\/]?>/', $content, $match);
        $images = $match[1];
    }
    //返回结果
    if($result == 'first'){
        return current($images);
    }elseif($result == 'last'){
        return end($images);
    }else{
        return $images;
    }
}

/**
 * 格式化标题颜色
 * @version 1.0.0 首次引入
 * @param string $color 必需;规定时间戳的格式;空
 * @param string $default 可选;默认颜色值;text-dark
 * @return string 格式化后颜色class伪类
 */
function cmsColor($color, $default='text-dark')
{
    return DcEmpty($color, $default);
}

/**
 * 对日期或时间进行格式化
 * @version 1.0.0 首次引入
 * @param string $format 必需;规定时间戳的格式;空
 * @param mixed $timestamp 可选;规定时间戳;空
 * @return string 格式化后的时间
 */
function cmsDate($format='Y-m-d', $timestamp='')
{
    if(!is_numeric($timestamp)){
        $timestamp = strtotime($timestamp);
    }
    return date($format, $timestamp);
}

/**
 * 替换全站搜索引擎关键字
 * @version 1.0.0 首次引入
 * @param string $route 必需;包含待替换的关键字;空
 * @param string $page 可选;页码;空
 * @return string 过滤后的文本
 */
function cmsSeo($string='', $page=0)
{
    if(!$string){
        return '欢迎使用呆错文章管理系统（DaiCuoCms）';
    }
    $page = DcEmpty($page, input('param.pageNumber/d',1) );
    $search = ['[siteName]', '[siteDomain]', '[pageNumber]'];
    $replace = [config('common.site_name'), config('common.site_domain'), $page];
    return str_replace($search, $replace, $string);
}

/**
 * 内容模型计数增加
 * @version 1.0.0 首次引入
 * @param int $id 必需;ID值;默认:空
 * @param string $field 必需;字段值;默认:info_views
 * @param int $numb 可选;步进值;默认:1
 * @param int $time 可选;延迟更新;默认:0
 * @return int 最新值
 */
function cmsInfoInc($id=0, $field='info_views', $num=1, $time=0){
    if(!$id){
        return 0;
    }
    return dbUpdateInc('common/Info', ['info_id'=>['eq',$id]], $field, $num, $time);
}

/**
 * 字符串截取
 * @version 1.0.0 首次引入
 * @param string $string 必需;待截取的字符串
 * @param int $start 必需;起始位置;默认：0
 * @param int $length 必需;截取长度;默认：420
 * @param bool $suffix 可选;超出长度是否以...显示;默认：true
 * @param string $charset 可选;字符编码;默认：utf-8
 * @return string $string 截取后的字符串
 */
function cmsSubstr($string, $start=0, $length=420, $suffix=true, $charset="UTF-8"){
    $string = strip_tags(htmlspecialchars_decode(cmsTrim($string)));
    return htmlspecialchars(DcSubstr($string, $start, $length, $suffix, $charset));
}

/**
 * 过滤连续空白
 * @version 1.0.0 首次引入
 * @param string $str 待过滤的字符串
 * @return string 处理后的字符串
 */
function cmsTrim($str=''){
    $str = str_replace("　",' ',str_replace("&nbsp;",' ',trim($str)));
    $str = preg_replace('#\s+#', ' ', $str);
    return $str;
}

/**********************************************************************************************************/
/**
 * 获取图片附件链接
 * @version 1.0.0 首次引入
 * @param string $file 必需;图片传件路径;默认：空
 * @param string $root 可选;根目录;默认：/
 * @param string $default 可选;默认图片地址;默认：x.gif
 * @return string 无图片时返回默认横向图
 */
function cmsUrlImage($file='', $root='/', $default='public/images/x.gif')
{
    return DcEmpty(DcUrlAttachment($file), $root.$default);
}

/**
 * 处理搜索页内部链接
 * @version 1.0.0 首次引入
 * @param array $args 必需;['searchText','pageNumber','pageSize','sortName','sortOrder'];默认:空
 * @param string $module 可选;模块名;默认:cms
 * @param string $controll 可选;控制器名;默认:search
 * @param string $action 可选;操作名;默认:index
 * @return string 生成的内部网址链接
 */
function cmsUrlSearch($args=[], $module='cms', $controll='search', $action='index')
{
    $args = DcArrayFilter($args,['searchText','pageNumber','pageSize','sortName','sortOrder']);
    $route = config('cms.rewrite_search');
    if( strpos($route,':pageSize') === false ){
        unset($args['pageSize']);
    }
    if( strpos($route,':sortName') === false ){
        unset($args['sortName']);
    }
    if( strpos($route,':sortOrder') === false ){
        unset($args['sortOrder']);
    }
    return DcUrl($module.'/'.$controll.'/'.$action, $args, '');
}

/**
 * 获取分类页内部链接
 * @version 1.0.0 首次引入
 * @param array $info 必需;[id,name,slug]；默认:空
 * @param mixed $pageNumber 可选;int|[PAGE];默认:空
 * @return string 生成的内部网址链接
 */
function cmsUrlCategory($info=[], $pageNumber='')
{
    $field = cmsUrlRewrite(config('cms.rewrite_category'));
    if(!$info['term_'.$field]){
        return 'javascript:;';
    }
    //默认参数
    $args = [
        $field => $info['term_'.$field]
    ];
    if($pageNumber){
        $args['pageNumber'] = $pageNumber;
    }
    //模型名
    $module = DcEmpty(str_replace('common', '', $info['term_module']), 'cms');
    //返回链接
    return DcUrl($module.'/category/index', $args, '');
}

/**
 * 获取标签页内部链接
 * @version 1.0.0 首次引入
 * @param array $info 必需;[id,name,slug]；默认:空
 * @param mixed $pageNumber 可选;int|[PAGE];默认:空
 * @return string 生成的内部网址链接
 */
function cmsUrlTag($info=[], $pageNumber='')
{
    $field = cmsUrlRewrite(config('cms.rewrite_tag'));
    if(!$info['term_'.$field]){
        return 'javascript:;';
    }
    //默认参数
    $args = [
        $field => $info['term_'.$field]
    ];
    if($pageNumber){
        $args['pageNumber'] = $pageNumber;
    }
    //模型名
    $module = DcEmpty(str_replace('common', '', $info['term_module']), 'cms');
    //返回链接
    return DcUrl($module.'/tag/index', $args, '');
}

/**
 * 获取详情页内部链接
 * @version 1.0.0 首次引入
 * @param array $info 必需;[id,name,slug]；默认：空
 * @param mixed $pageNumber 可选;int|[PAGE];默认:空
 * @return string 生成的内部网址链接
 */
function cmsUrlDetail($info, $pageNumber='')
{
    //URL参数
    $args = [];
    //模型名
    $module = DcEmpty(str_replace('common', '', $info['info_module']), 'cms');
    //组合路由
    $fields = cmsUrlCompose(config('cms.rewrite_detail'));
    if($fields){
        $info['info_termSlug'] = DcEmpty($info["category_slug"][0],'unclass');
        $info['info_termId']   = intval($info["category_id"][0]);
        $info['info_termName'] = DcEmpty($info["category_name"][0],'未分类');
        foreach($fields as $key=>$field){
            $args[$field] = $info['info_'.$field];
        }
        return DcUrl($module.'/detail/index', $args, '');
    }
    //普通路由
    $field = cmsUrlRewrite(config('cms.rewrite_detail'));
    //数据验证
    if(!$info['info_'.$field]){
        return 'javascript:;';
    }
    //变量字段
    $args[$field] = $info['info_'.$field];
    //分页参数
    if($pageNumber){
        $args['pageNumber'] = $pageNumber;
    }
    return DcUrl($module.'/detail/index', $args, '');
}

/**
 * 获取单页内部链接
 * @version 1.0.0 首次引入
 * @param array $info 必需;[id,name,slug]；默认:空
 * @param mixed $pageNumber 可选;int|[PAGE];默认:空
 * @return string 生成的内部网址链接
 */
function cmsUrlPage($info, $pageNumber='')
{
    //数据验证
    $field = cmsUrlRewrite(config('cms.rewrite_page'));
    if(!$info['info_'.$field]){
        return 'javascript:;';
    }
    //分页参数
    $args = [
        $field => $info['info_'.$field]
    ];
    if($pageNumber){
        $args['pageNumber'] = $pageNumber;
    }
    //模型名
    $module = DcEmpty(str_replace('common', '', $info['info_module']), 'cms');
    //链接函数
    return DcUrl($module.'/page/index', $args, '');
}

/**
 * 根据伪静态规则返回组合路由的变量字段
 * @version 1.0.0 首次引入
 * @param string $route 必需;伪静态规则名;空
 * @return array 组合查询字段 
 */
function cmsUrlCompose($route='')
{
    $fields = [];
    /*preg_match_all(/'<[A-Za-z]+(\?)?>'/,$route,$item);*/
    preg_match_all('/<[termSlug|termId|termName|slug|id|name]+(\?)?>/', $route, $item);
    foreach($item[0] as $key=>$field){
        $fields[$key] = str_replace(['<','>','?'], '', $field);
    }
    return $fields;
}

/**
 * 根据伪静态规则关键字返回对应的字段名
 * @version 1.0.0 首次引入
 * @param string $route 必需;伪静态规则名;空
 * @return string 操作名
 */
function cmsUrlRewrite($route='')
{
    if( strpos($route,':slug') !== false ){
        return 'slug';
    }elseif( strpos($route,':name') !== false ){
        return 'name';
    }
    return 'id';
}

/**
 * 获取默认地址栏参数
 * @version 1.0.0 首次引入
 * @param string $sort 可选;排序字段;默认：info_id
 * @param string $order 可选;排序方式;默认：desc
 * @param string $limit 可选;每页大小;默认：10
 * @param string $page 可选;当前分页;默认：1
 * @return array 默认地址栏五个参数
 */
function cmsUrlParams($sort='info_id', $order='desc', $limit=10, $page=1)
{
    return [
        'sort'   => htmlspecialchars(input('param.sortName/s',$sort)),
        'order'  => htmlspecialchars(input('param.sortOrder/s',$order)),
        'limit'  => input('param.pageSize/d', DcEmpty(config('cms.page_size'),$limit)),
        'page'   => input('param.pageNumber/d', $page),
        'search' => htmlspecialchars(strip_tags(input('param.searchText/s'))),
    ];
}

/**
 * 智能转换内部与外部网址链接
 * @version 1.0.0 首次引入
 * @param string $url 必需;待验证的网址;默认：空
 * @return string 转换后的链接
 */
function cmsUrlCheck($url='')
{
    //默认值
    $url = DcEmpty($url, 'cms/index/index');
    //分解地址栏
    $array = parse_url($url);
    if($array['scheme']){
        return $url;
    }
    //内部链接
    return DcUrl($array['path'], $array['query'], '');
}