<?php
namespace app\cms\event;

class Sql
{
    /**
    * 安装时触发
    * @return bool 只有返回true时才会往下执行
    */
	public function install()
    {
        //批量添加配置
        $this->insertConfig();
        
        //批量添加路由
        $this->insertRoute();
        
        //批量添加权限
        $this->insertAuth();
        
        //批量添加分类/标签/导航
        $this->insertTerm();
        
        //返回结果
        return true;
	}
    
    /**
    * 升级时触发
    * @return bool 只有返回true时才会往下执行
    */
    public function upgrade()
    {
        return true;
    }
    
    /**
    * 卸载时触发
    * @return bool 只有返回true时才会往下执行
    */
    public function remove()
    {
        return $this->unInstall();
    }
    
    /**
    * 删除时触发
    * @return bool 只有返回true时才会往下执行
    */
    public function unInstall()
    {
        //删除插件配置
        \daicuo\Op::delete_module('cms');
        //删除插件分类
        \daicuo\Term::delete_module('cms');
        //直接返回结果
        return true;
	}
    
    //批量添加初始配置
    private function insertConfig()
    {
        return \daicuo\Op::write([
            'theme'             => 'default',
            'theme_wap'         => 'default',
            'index_title'       => '呆错文章系统',
            'index_keywords'    => '新闻发布系统,文章管理系统,文章系统,文章CMS,新闻CMS',
            'index_description' => '呆错文章系统是一款基于呆错后台开发框架研发的文章管理系统，被广泛应用于搭建博客、行业站、企业站、产品展示等。',
            'slug_first'        => 1,
            'search_interval'   => 0,
            'page_size'         => 30,
            'rewrite_index'     => '/cms$',
        ],'cms','system','config','0','yes');
    }
    
    //批量添加路由
    private function insertRoute()
    {
        return \daicuo\Route::save_all([
            [
                'rule'        => '/cms$',
                'address'     => 'cms/index/index',
                'method'      => '*',
                'op_module'   => 'cms',
                'op_controll' => 'system',
                'op_action'   => 'route',
            ],
        ]);
    }
    
    //批量添加初始权限
    private function insertAuth()
    {
        \daicuo\Op::delete_all(['op_module'=>'cms','op_controll'=>'system','op_action'=>'auth']);
        
        return \daicuo\Op::save_all([
            [
                'op_name'       => 'guest',
                'op_value'      => 'cms/index/index',
                'op_module'     => 'cms',
                'op_controll'   => 'system',
                'op_action'     => 'auth',
                'op_order'      => 0,
                'op_status'     => 'normal',
            ],
        ]);
    }
    
    //批量添加分类/标签/导航
    private function insertTerm()
    {
        DcConfigMerge('custom_fields.term_meta', ['navs_target','navs_url','navs_image','navs_active','navs_class']);
        
        return \daicuo\Term::save_all([
            [
                'term_name'       => '分类测试',
                'term_slug'       => 'categorytest',
                'term_module'     => 'cms',
                'term_controll'   => 'category',
                'term_action'     => 'index',
                'term_status'     => 'normal',
                'term_order'      => 0,
                'term_parent'     => 0,
                'term_type'       => 'category',
                'term_navbar'     => 'no',
                'term_info'       => '我是分类测试的说明，后台>系统>分类管理',
                'term_tpl'        => 'index',
            ],
            [
                'term_name'       => '标签测试',
                'term_slug'       => 'tagtest',
                'term_module'     => 'cms',
                'term_controll'   => 'tag',
                'term_action'     => 'index',
                'term_status'     => 'normal',
                'term_order'      => 0,
                'term_parent'     => 0,
                'term_type'       => 'tag',
                'term_navbar'     => 'no',
                'term_info'       => '我是标签测试的说明，后台>系统>标签管理',
                'term_tpl'        => 'index',
            ],
            [
                'term_name'       => '菜单测试',
                'term_slug'       => 'navstest',
                'term_module'     => 'cms',
                'term_controll'   => 'navs',
                'term_action'     => 'navbar',
                'term_status'     => 'normal',
                'term_order'      => 0,
                'term_parent'     => 0,
                'term_type'       => 'navs',
                'term_info'       => '我是菜单测试的说明，后台>系统>菜单管理',
                'term_tpl'        => 'index',
                'navs_url'        => 'cms/index/index',
                'navs_active'     => 'cmsindexindex',
            ],
        ]);
    }
	
}