<?php
namespace app\cms\loglic;

class Article
{
    // 错误信息
    protected $error = '';
    
    /**
     * 获取错误信息
     * @return mixed
     */
    public function getError()
    {
        return $this->error;
    }
    
    /**
    * 添加文章高级用法（自定义场景与规则）
    * @version 1.0.0 首次引入
    * @param array $post 必需;数组格式,支持的字段列表请参考手册
    * @param bool $autoTerm 必需;当分类与标签不存在时是否自动新增;默认:false
    * @param string $action 必需;新增或修改(save|update);默认:save
    * @param string $scene 可选;验证场景(save|update|slugUnique|refererUnique);默认:slugUnique
    * @param array $sceneRule 可选;自定义验证规则;默认:无
    * @param array $slugRule 可选;别名规则;默认:false
    * @return mixed 成功时返回obj,失败时null
    */
    public function write($post=[], $autoTerm=false, $action='save', $scene='slugUnique', $sceneRule=[], $slugRule=false)
    {
        //数据格式化（修改器）
        $post = DcArrayArgs($post,[
            'info_module'   => 'cms',
            'info_controll' => 'detail',
            'info_action'   => 'index',
            'info_staus'    => 'normal',
            'info_type'     => 'index',
        ]);
        $post = articleDataSet($post, $autoTerm);

        //取消框架模块验证
        config('common.validate_name', false);
        config('common.validate_scene', false);
        //自定义验证器与验证规则
        if($scene){
            //实例化验证器
            $validate = validate('cms/Article', 'validate');
            //自定义验证场景规则
            if($sceneRule){
                $validate->scene($scene, $sceneRule);
            }
            //表单验证结果（失败）
            if(!$validate->scene($scene)->check($post)){
                $this->error = $validate->getError();
                return null;
            }
        }

        //定义框架别名处理规则（默认取消别名检测false）
        config('common.where_slug_unique', $slugRule);
        //config('common.where_slug_unique',['info_module'=>['eq','cms'],'info_controll'=>['eq','detail']]);
        //调用数据库接口
        if($action == 'save'){
            return \daicuo\Info::save($post, 'info_meta,term_map');
        }else if($action == 'update'){
            return DcArrayResult(\daicuo\Info::update_id($post['info_id'], $post, 'info_meta,term_map'));
        }
        //默认返回
        return null;
    }
    
    /**
    * 表单字段通用属性处理
    * @version 1.0.0 首次引入
    * @param array $data 可选;初始数据;默认：空
    * @return array 表单字段数组列表（DcBuildForm）
    */
    public function items($data=[])
    {
        //获取表单字段列表
        $fields = $this->fields($data);
        //增加字段的相同属性值
        foreach($fields as $key=>$value){
            if(!isset($fields[$key]['class_left'])){
                $fields[$key]['class_left'] = 'col-12';
            }
            if(!isset($fields[$key]['class_right'])){
                $fields[$key]['class_right'] = 'col-12';
            }
            $fields[$key]['class_tips']  = '';
        }
        //表单字段（格式化）
        return DcFormItems($fields);
    }
    
    /**
    * 表格选项通用属性处理
    * @version 1.0.0 首次引入
    * @param array $data 可选;初始数据;默认：空
    * @return array 表格列字段属性（DcBuildTable）
    */
    public function columns($data=[])
    {
        $columns = DcTableColumns( $this->fields($data) );
        
        $columns['operate']['data-events'] = 'daicuo.admin.cms.events';
        
        return $columns;
    }
    
    /**
    * 定义文章模型的字段
    * @version 1.0.0 首次引入
    * @param array $data 可选;初始数据;默认：空
    * @return array 表格列字段属性（DcBuildTable）
    */
    public function fields($data)
    {
        $fields = [
            'info_html_1' => [
                'type'            => 'html',
                'value'           => '<div class="row"><div class="col-12 col-md-8">',
                'order'           => 1,
            ],
            'info_id' => [
                'type'            => 'hidden',
                'value'           => $data['info_id'],
                'order'           => 2,
                'data-title'      => lang('article_id'),
                'data-filter'     => false,
                'data-visible'    => true,
                'data-sortable'   => true,
                'data-width'      => '60',
                //'data-width-unit' => 'px',
            ],
            'info_user_id' => [
                'type'            => 'hidden',
                'value'           => DcUserCurrentGetId(),
                'order'           => 3,
                'data-filter'     => false,
                'data-visible'    => false,
            ],
            'info_name' => [
                'type'            => 'text',
                'value'           => $data['info_name'],
                'order'           => 11,
                'title'           => lang('article_name'),
                'placeholder'     => lang('article_name_placeholder'),
                'data-filter'     => false,
                'data-visible'    => true,
                'data-align'      => 'left',
                'data-class'      => 'text-wrap',
            ],
            'info_slug' => [
                'type'            => 'text',
                'value'           => $data['info_slug'],
                'order'           => 21,
                'title'           => lang('article_slug'),
                'data-filter'     => false,
                'data-visible'    => false,
            ],
            'info_cover' => [
                'type'            => 'image',
                'value'           => $data['info_cover'],
                'order'           => 31,
                'title'           => lang('article_cover'),
                'placeholder'     => '',
                'data-filter'     => false,
                'data-visible'    => false,
            ],
            'info_excerpt' => [
                'type'            => 'textarea',
                'value'           => $data['info_excerpt'],
                'order'           => 41,
                'rows'            => 3,
                'data-filter'     => false,
                'data-visible'    => false,
            ],
            'info_content' => [
                'type'            => 'editor',
                'value'           => $data['info_content'],
                'order'           => 51,
                'title'           => lang('article_content'),
                'rows'            => 70,
                'height'          => '75rem',
                'data-filter'     => false,
                'data-visible'    => false,
            ],
            'info_html_2' => [
                'type'            => 'html',
                'value'           => '</div><div class="col-12 col-md-4">',
                'order'           => 199,
            ],
            'category_id' => [
                'type'            => 'checkbox',
                'value'           => $data['category_id'],
                'order'           => 201,
                'option'          => DcTermCheck(['module'=>['in','cms,common']]),
                'title'           => lang('article_category'),
                'class_right'     =>'col-12 pre-scrollable',
                //'class_right'   =>'col-12 pr-0',
                //'class_right_check'=>'col-4 form-check form-check-inline py-1 px-0',
            ],
            'tag_name'  => [
                'type'            =>'tags',
                'value'           => implode(',',$data['tag_name']),
                'order'           => 211,
                'option'          => cmsTags(10),
                'title'           => lang('article_tag'),
                'placeholder'     => '',
                'class_tags'      => 'form-text pt-1',
                'class_tags_list' => 'text-purple mr-2',
            ],
            'info_status' => [
                'type'            => 'select',
                'value'           => DcEmpty($data['info_status'],'normal'),
                'order'           => 221,
                'option'          => ['normal'=>lang('normal'),'hidden'=>lang('hidden'),'private'=>lang('private')],
                'title'           => lang('article_status'),
                'data-filter'     => true,
                'data-visible'    => false,
                'data-width'      => '100',
                'data-width-unit' => 'px',
            ],
            'info_status_text' => [
                'order'           => 221,
                'data-title'      => lang('article_status'),
                'data-visible'    => true,
            ],
            'info_create_time' => [
                'order'           => 221,
                'data-visible'    => true,
            ],
            'info_update_time' => [
                'order'           => 221,
                'data-visible'    => true,
            ],
            'info_type' => [
                'type'            => 'select',
                'value'           => DcEmpty($data['info_type'],'index'),
                'order'           => 231,
                'option'          => articleTypeOption(),
                'title'           => lang('article_type'),
                'data-title'      => lang('article_type'),
                'data-filter'     => true,
                'data-visible'    => true,
                'data-width'      => '100',
                'data-width-unit' => 'px',
            ],
            'info_color'       => [
                'type'            => 'select',
                'value'           => DcEmpty($data['info_color'],'text-dark'),
                'order'           => 241,
                'option'          => [
                    'text-dark'      => 'text-dark',
                    'text-danger'    => 'text-danger',
                    'text-success'   => 'text-success',
                    'text-primary'   => 'text-primary',
                    'text-info'      => 'text-info',
                    'text-secondary' => 'text-secondary',
                    'text-muted'     => 'text-muted',
                    'text-light'     => 'text-light',
                ],
                'title'              => lang('article_color'),
                'data-filter'        => true,
                'data-visible'       => false,
            ],
            'article_attr' => [
                'type'              => 'checkbox',
                'value'             => articleAttrValue($data),
                'order'             => 251,
                'option'            => articleAttrOption(),
                'class_right_check' => 'form-check form-check-inline',
                'data-filter'       => true,
                'data-visible'      => false,
                'data-width'        => '100',
            ],
            'info_referer' => [
                'type'            => 'text',
                'value'           => $data['info_referer'],
                'order'           => 261,
                'title'           => lang('article_referer'),
                'placeholder'     => lang('article_referer_placeholder'),
                'data-filter'     => false,
                'data-visible'    => false,
            ],
            'info_tpl' => [
                'type'            => 'text',
                'value'           => $data['info_tpl'],
                'order'           => 271,
                'data-filter'     => false,
                'data-visible'    => false,
            ],
            'info_order' => [
                'type'            => 'number',
                'value'           => intval($data['info_order']),
                'order'           => 281,
                'data-filter'     => false,
                'data-visible'    => true,
                'data-sortable'   => true,
            ],
            'info_views' => [
                'type'            => 'number',
                'value'           => intval($data['info_views']),
                'order'           => 291,
                'data-filter'     => false,
                'data-visible'    => true,
                'data-sortable'   => true,
            ],
            'info_hits' => [
                'type'            => 'number',
                'value'           => intval($data['info_hits']),
                'order'           => 301,
                'data-filter'     => false,
                'data-visible'    => true,
                'data-sortable'   => true,
            ],
            'info_up' => [
                'type'            => 'number',
                'value'           => intval($data['info_up']),
                'order'           => 311,
                'title'           => lang('article_up'),
                'data-title'      => lang('article_up'),
                'data-filter'     => false,
                'data-visible'    => true,
                'data-sortable'   => true,
            ],
            'info_down' => [
                'type'            => 'number',
                'value'           => intval($data['info_down']),
                'order'           => 321,
                'title'           => lang('article_down'),
                'data-title'      => lang('article_down'),
                'data-filter'     => false,
                'data-visible'    => true,
                'data-sortable'   => true,
            ],
            'info_letter' => [
                'type'            => 'text',
                'value'           => $data['info_letter'],
                'order'           => 322,
                'title'           => lang('info_letter'),
                'data-title'      => lang('info_letter'),
                'data-filter'     => false,
                'data-visible'    => true,
            ],
            'info_image' => [
                'type'            => 'image',
                'value'           => $data['info_image'],
                'order'           => 331,
                'multiple'        => true,
                'title'           => lang('article_image'),
                'placeholder'     => '',
                'data-filter'     => false,
                'data-visible'    => false,
                'data-sortable'   => true,
            ],
            'info_slide' => [
                'type'            => 'image',
                'value'           => $data['info_slide'],
                'order'           => 341,
                'title'           => lang('article_slide'),
                'placeholder'     => '',
                'data-filter'     => false,
                'data-visible'    => false,
            ],
            'info_title' => [
                'type'            => 'text',
                'value'           => $data['info_title'],
                'order'           => 351,
                'title'           => lang('seo_title'),
                'data-filter'     => false,
                'data-visible'    => false,
            ],
            'info_keywords' => [
                'type'            => 'text',
                'value'           => $data['info_keywords'],
                'order'           => 361,
                'title'           => lang('seo_keywords'),
                'data-filter'     => false,
                'data-visible'    => false,
            ],
            'info_description' => [
                'type'            => 'text',
                'value'           => $data['info_description'],
                'order'           => 371,
                'title'           => lang('seo_description'),
                'data-filter'     => false,
                'data-visible'    => false,
            ],
            'info_html_3'      => [
                'type'            => 'html',
                'value'           => '</div></div>',
                'order'           => 999,
            ]
        ];
        
        return list_sort_by($fields, 'order', 'asc', true);
    }
}