<?php
namespace app\cms\loglic;

class Category
{
    /**
    * 表单字段通用属性处理
    * @version 1.0.0 首次引入
    * @param array $data 可选;初始数据;默认：空
    * @return array 表单字段数组列表（DcBuildForm）
    */
    public function items($data=[])
    {
        //获取表单字段列表
        $fields = $this->fields($data);
        //增加字段的相同属性值
        foreach($fields as $key=>$value){
            $fields[$key]['class_left']  = 'col-12';
            $fields[$key]['class_right'] = 'col-12';
            $fields[$key]['class_tips']  = '';
            $fields[$key]['placeholder']  = '';
        }
        //表单字段（格式化）
        return DcFormItems($fields);
    }
    
    /**
    * 表格选项通用属性处理
    * @version 1.0.0 首次引入
    * @param array $data 可选;初始数据;默认：空
    * @return array 表格列字段属性（DcBuildTable）
    */
    public function columns($data=[])
    {
        $columns = DcTableColumns( $this->fields($data) );
        
        $columns['operate']['data-events'] = 'daicuo.admin.cms.eventsNavs';
        
        return $columns;
    }
    
    /**
    * 定义栏目模型的字段
    * @version 1.0.0 首次引入
    * @param array $data 可选;初始数据;默认：空
    * @return array 表格列字段属性（DcBuildTable）
    */
    public function fields($data)
    {
        return [
            'html_1' => [
                'type'            => 'html',
                'value'           => '<div class="row"><div class="col-12 col-md-8">',
                'order'           => 0,
            ],
            'term_id' => [
                'type'            => 'hidden',
                'value'           => $data['term_id'],
                'order'           => 1,
                'data-filter'     => false,
                'data-visible'    => true,
                'data-width'      => '80',
                'data-width-unit' => 'px',
                'data-sortable'   => true,
                'data-sort-name'  => 'term_id',
                'data-order'      => 'asc',
            ],
            'term_parent' => [
                'type'            => 'select',
                'value'           => $data['term_parent'],
                'order'           => 11,
                'option'          => DcTermOption(['module'=>'cms']),
                'data-width'      => 100,
            ],
            'term_type' => [
                'type'            => 'hidden',
                'value'           => 'category',
                'order'           => 21,
                'data-filter'     => false,
                'data-visible'    => false,
            ],
            'term_name' => [
                'type'            => 'text',
                'value'           => $data['term_name'],
                'order'           => 31,
                'required'        => true,
                'data-filter'     => false,
                'data-visible'    => true,
                'data-align'      => 'left',
            ],
            'term_slug' => [
                'type'            => 'text',
                'value'           => $data['term_slug'],
                'order'           => 41,
                'data-filter'     => false,
                'data-visible'    => true,
                'data-align'      => 'left',
            ],
            'term_image' => [
                'type'            => 'image',
                'value'           => $data['term_image'],
                'order'           => 51,
            ],
            'term_status' => [
                'type'            => 'select',
                'value'           => DcEmpty($data['term_status'],'normal'),
                'option'          => ['normal'=>lang('normal'),'hidden'=>lang('hidden'),'private'=>lang('private')],
                'order'           => 61,
                'data-filter'     => true,
                'data-visible'    => false,
            ],
            'term_status_text' => [
                'order'           => 61,
                'data-title'      => lang('term_status'),
                'data-visible'    => true,
                'data-width'      => 100,
            ],
            'term_title' => [
                'type'            => 'text',
                'value'           => $data['term_title'],
                'order'           => 71,
            ],
            'term_keywords' => [
                'type'            => 'text',
                'value'           => $data['term_keywords'],
                'order'           => 81,
            ],
            'term_description' => [
                'type'            => 'text',
                'value'           => $data['term_description'],
                'order'           => 91,
            ],
            'term_info' => [
                'type'            => 'textarea',
                'value'           => $data['term_info'],
                'rows'            => 5,
                'order'           => 101,
                'data-filter'     => false,
                'data-visible'    => false,
            ],
            'html_2'      => [
                'type'            => 'html',
                'value'           => '</div><div class="col-12 col-md-4">',
                'order'           => 199,
            ],
            'term_navbar'=> [
                'type'             => 'custom',
                'value'            => $data['term_navbar'],
                'option'           => ['no'=>'no','yes'=>'yes'],
                'order'            => 301,
                'data-visible'     => true,
                'data-width'       => 100,
            ],
            'term_count' => [
                'order'           => 311,
                'data-visible'    => true,
                'data-sortable'   => true,
                'data-width'      => '100',
            ],
            'term_order' => [
                'type'            => 'number',
                'value'           => intval($data['term_order']),
                'order'           => 311,
                'data-filter'     => false,
                'data-visible'    => true,
                'data-width'      => '100',
                'data-sortable'   => true,
            ],
            'term_action' => [
                'type'            => 'text',
                'value'           => DcEmpty($data['term_action'],'index'),
                'order'           => 341,
                'data-filter'     => false,
                'data-visible'    => true,
                'data-width'      => '100',
            ],
            'term_controll' => [
                'type'            => 'text',
                'value'           => DcEmpty($data['term_controll'],'category'),
                'order'           => 331,
                'data-filter'     => false,
                'data-visible'    => true,
                'data-width'      => '100',
            ],
            'term_module' => [
                'type'            => 'text',
                'value'           => DcEmpty($data['term_module'],'cms'),
                'order'           => 321,
                'data-filter'     => false,
                'data-visible'    => true,
                'data-width'      => '100',
            ],
            'term_tpl'   => [
                'type'             => 'text',
                'value'            => 'index',
                'order'            => 351,
            ],
            'html_3' => [
              'type'              => 'html',
              'value'             => '</div></div>',
              'order'             => 999,
            ]
        ];
    }
}