<?php
namespace app\cms\loglic;

class Page
{
    /**
    * 表单字段通用属性处理
    * @version 1.0.0 首次引入
    * @param array $data 可选;初始数据;默认：空
    * @return array 表单字段数组列表（DcBuildForm）
    */
    public function items($data=[])
    {
        //获取表单字段列表
        $fields = $this->fields($data);
        //增加字段的相同属性值
        foreach($fields as $key=>$value){
            $fields[$key]['class_left']  = 'col-12';
            $fields[$key]['class_right'] = 'col-12';
            $fields[$key]['class_tips']  = '';
        }
        //表单字段（格式化）
        return DcFormItems($fields);
    }
    
    /**
    * 表格选项通用属性处理
    * @version 1.0.0 首次引入
    * @param array $data 可选;初始数据;默认：空
    * @return array 表格列字段属性（DcBuildTable）
    */
    public function columns($data=[])
    {
        $columns = DcTableColumns( $this->fields($data) );
        
        $columns['operate']['data-events'] = 'daicuo.admin.cms.events';
        
        return $columns;
    }
    
    /**
    * 定义单页模型的字段
    * @version 1.0.0 首次引入
    * @param array $data 可选;初始数据;默认：空
    * @return array 表格列字段属性（DcBuildTable）
    */
    public function fields($data)
    {
        $fields = [
            'info_html_1' => [
                'type'  => 'html',
                'value' => '<div class="row"><div class="col-12 col-md-9">',
                'order' => 0,
            ],
            'info_id' => [
                'type'  => 'hidden',
                'value' => $data['info_id'],
                'order' => 1,
            ],
            'info_type' => [
                'type'  => 'hidden',
                'value' => 'page',
                'order' => 1,
            ],
            'info_module' => [
                'type'  => 'hidden',
                'value' => 'cms',
                'order' => 1,
            ],
            'info_controll' => [
                'type'  => 'hidden',
                'value' => 'page',
                'order' => 1,
            ],
            'info_user_id' => [
                'type'  => 'hidden',
                'value' => DcUserCurrentGetId(),
                'order' => 1,
            ],
            'info_name' => [
                'type'            => 'text',
                'value'           => $data['info_name'],
                'order'           => 1,
                'data-visible'    => true,
                'data-align'      => 'left',
                'data-class'      => 'text-wrap',
            ],
            'info_slug' => [
                'type'            => 'text',
                'value'           => $data['info_slug'],
                'order'           => 11,
                'data-filter'     => false,
                'data-visible'    => true,
                'data-align'      => 'left',
                'data-width'      => 150,
            ],
            'info_excerpt' => [
                'type'            => 'text',
                'value'           => $data['info_excerpt'],
                'order'           => 21,
            ],
            'info_content' => [
                'type'            => 'editor',
                'value'           => $data['info_content'],
                'order'           => 31,
                'rows'            => 50,
                'height'          => '50rem',
            ],
            'info_html_2' => [
                'type'            => 'html',
                'value'           => '</div><div class="col-12 col-md-3">',
                'order'           => 199,
            ],
            'info_status' => [
                'type'            => 'select',
                'value'           => $data['info_status'],
                'option'          => ['normal'=>lang('normal'),'hidden'=>lang('hidden'),'private'=>lang('private')],
                'order'           => 201,
                'data-filter'     => true,
            ],
            'info_status_text' => [
                'order' => 201,
                'data-title'      => lang('info_status'),
                'data-filter'     => false,
                'data-visible'    => true,
                'data-width'      => 100,
            ],
            'info_order' => [
                'type'            => 'number',
                'value'           => intval($data['info_order']),
                'order'           => 211,
                'data-filter'     => false,
                'data-visible'    => true,
                'data-sortable'   => true,
                'data-width'      => 100,
            ],
            'info_views' => [
                'type'            => 'number',
                'value'           => intval($data['info_views']),
                'order'           => 221,
                'data-filter'     => false,
                'data-visible'    => true,
                'data-sortable'   => true,
                'data-width'      => 100,
            ],
            'info_hits' => [
                'type'            => 'number',
                'value'           => intval($data['info_hits']),
                'order'           => 231,
                'data-filter'     => false,
                'data-visible'    => true,
                'data-sortable'   => true,
                'data-width'      => 100,
            ],
            'info_up' => [
                'type'            => 'number',
                'value'           => intval($data['info_up']),
                'order'           => 241,
                'title'           => lang('article_up'),
                'data-title'      => lang('article_up'),
                'data-filter'     => false,
                'data-visible'    => true,
                'data-sortable'   => true,
                'data-width'      => 100,
            ],
            'info_down' => [
                'type'            => 'number',
                'value'           => intval($data['info_down']),
                'order'           => 251,
                'title'           => lang('article_down'),
                'data-title'      => lang('article_down'),
                'data-filter'     => false,
                'data-visible'    => true,
                'data-sortable'   => true,
                'data-width'      => 100,
            ],
            'info_tpl' => [
                'type'            => 'text',
                'value'           => DcEmpty($data['info_tpl'],'index'),
                'order'           => 261,
                'data-filter'     => false,
                'data-visible'    => true,
                'data-width'      => 100,
            ],
            'info_title' => [
                'type'            => 'text',
                'value'           => $data['info_title'],
                'order'           => 271,
            ],
            'info_keywords' => [
                'type'            => 'text',
                'value'           => $data['info_keywords'],
                'order'           => 281,
            ],
            'info_description' => [
                'type'            => 'text',
                'value'           => $data['info_description'],
                'order'           => 291,
            ],
            'info_html_3' => [
              'type'              => 'html',
              'value'             => '</div></div>',
              'order'             => 999,
            ]
        ];
        
        return list_sort_by($fields, 'order', 'asc', true);
    }
}